<?php
/*
Simple:Press Plugin Title: Editor TinyMCE Rich Text
Version: 3.0.4
Plugin URI: http://simple-press.com
Description: Rich Text Editor using WP TinyMCE
Author: Andy Staines & Steve Klasen
Author URI: http://simple-press.com
Simple:Press Versions: 5.5 and above
$LastChangedDate: 2014-06-07 14:32:19 -0700 (Sat, 07 Jun 2014) $
$Rev: 11528 $
*/

if (preg_match('#'.basename(__FILE__).'#', $_SERVER['PHP_SELF'])) die('Access denied - you cannot directly call this file');

define('SPTMDB', 4);

# ======================================
# EDITOR CONSTANTS
#	Must be one of:
#	RICHTEXT 	- 1
#	HTML		- 2
#	BBCODE		- 3
# ======================================
define('RICHTEXT',		1);
define('RICHTEXTNAME',	'TinyMCE');

# ======================================
# CONSTANTS USED BY THIS PLUGIN
# ======================================
define('SPTMDIR',		    SFPLUGINDIR.'tinymce-richtext/');
define('SPTMLIB',		    SFPLUGINDIR.'tinymce-richtext/library/');
define('SPTMADMIN',	        SFPLUGINDIR.'tinymce-richtext/admin/');
define('SPTMTMSCRIPT',	    SFPLUGINURL.'tinymce-richtext/tinymce/');
define('SPTMSPSCRIPT',	    SFPLUGINURL.'tinymce-richtext/resources/jscript/');
define('SPTMCSS',		    SFPLUGINURL.'tinymce-richtext/resources/css/');
define('SPTMCONTENTSKIN',   SFPLUGINURL.'tinymce-richtext/resources/skins/SPlightgray');
define('SPTMPLUGINS',       SFPLUGINURL.'tinymce-richtext/resources/plugins/');

# ======================================
# ACTIONS/FILTERS USED BY THUS PLUGIN
# ======================================
add_action('sph_activate_tinymce-richtext/sp-tinymce-plugin.php',	    'sp_tinymce_install');
add_action('sph_uninstall_tinymce-richtext/sp-tinymce-plugin.php',      'sp_tinymce_uninstall');
add_action('init',												        'sp_tinymce_localisation');
add_action('sph_load_editor_support', 							        'sp_tinymce_load_filters', 1, 1);
add_action('sph_load_editor',									        'sp_tinymce_load');
add_action('sph_admin_menu',								 	        'sp_tinymce_admin_menu');
add_action('sph_plugin_update_tinymce-richtext/sp-tinymce-plugin.php',  'sp_tinymce_upgrade');
add_action('admin_footer',                                              'sp_tinymce_upgrade');

add_filter('sph_plugins_active_buttons',						 'sp_tinymce_uninstall_option', 10, 2);
add_filter('sph_editor_textarea',								 'sp_tinymce_textarea', 1, 5);
add_filter('sph_admin_help-admin-components', 					 'sp_tinymce_admin_help', 10, 3);
add_filter('sph_ProfilePostingOptionsFormEditors',				 'sp_tinymce_profile_option', 1, 2);
add_filter('sph_acknowledgements', 					             'sp_tinymce_acknowledge');
add_filter('user_can_richedit',                                  'sp_tinymce_use_editor');
add_filter('sph_this_editor',                                    'sp_tinymce_editor', 9999);

# ======================================
# CONTROL FUNCTIONS USED BY THUS PLUGIN
# ======================================

# ----------------------------------------------
# Run Install Script on Activation action
# ----------------------------------------------
function sp_tinymce_install() {
	include_once(SPTMDIR.'sp-tinymce-install.php');
	sp_tinymce_do_install();
}

# ----------------------------------------------
# Run Uninstall Script on Uninstall actiopn
# ----------------------------------------------
function sp_tinymce_uninstall() {
	include_once(SPTMDIR.'sp-tinymce-uninstall.php');
	sp_tinymce_do_uninstall();
}

# ------------------------------------------------------
# Add the 'Uninstall' and 'Options' link to plugins list
# ------------------------------------------------------
function sp_tinymce_uninstall_option($actionlink, $plugin) {
	if ($plugin == 'tinymce-richtext/sp-tinymce-plugin.php') {
		$url = SFADMINPLUGINS.'&amp;action=uninstall&amp;plugin='.$plugin.'&amp;sfnonce='.wp_create_nonce('forum-adminform_plugins');
		$actionlink.= "&nbsp;&nbsp;<a href='$url' title='".__('Uninstall this plugin', 'sp-tinymce')."'>".__('Uninstall', 'sp-tinymce').'</a>';

		$url = SFADMINCOMPONENTS.'&amp;tab=plugin&amp;admin=sp_tinymce_form&amp;save=sp_tinymce_save&amp;form=1';
		$actionlink.= "&nbsp;&nbsp;<a href='$url' title='".__('Options', 'sp-tinymce')."'>".__('Options', 'sp-tinymce').'</a>';
	}
	return $actionlink;
}

function sp_tinymce_upgrade() {
	include_once(SPTMDIR.'sp-tinymce-upgrade.php');
	sp_tinymce_do_upgrade();
}

# ----------------------------------------------
# Set GetText Localisation Domain
# ----------------------------------------------
function sp_tinymce_localisation() {
	sp_plugin_localisation('sp-tinymce');
}

function sp_tinymce_editor($editor) {
    if ($editor == RICHTEXT && !sp_tinymce_use_editor(false)) $editor = 4;
    return $editor;
}

# ----------------------------------------------
# Load the tinymce filter file
# ----------------------------------------------
function sp_tinymce_load_filters($editor) {
	if ($editor == RICHTEXT) {
		include_once(SPTMLIB.'sp-tinymce-filters.php');
	}
}

# ----------------------------------------------
# Load and Initialise this Editor if needed
# ----------------------------------------------
function sp_tinymce_load($editor) {
	if ($editor == RICHTEXT) {
        $script = (defined('SP_SCRIPTS_DEBUG') && SP_SCRIPTS_DEBUG) ? SPTMSPSCRIPT.'sp-tinymce-dev.js' : SPTMSPSCRIPT.'sp-tinymce.js';
        wp_enqueue_script('tinymce_richtext', $script, array('editor'), false, true);

        # enqueue css - tinymce css not really depenent on jquery ui css, but this forces it to load in head
        # as wp enqueues it when you instantiate the editor which we dont do until much later when needed
        $tinyCSS = sp_find_css(SPTMCSS, 'sp-tinymce.css');
        wp_enqueue_style('sp-tm', $tinyCSS, array('wp-jquery-ui-dialog'));
	}
}

function sp_tinymce_use_editor($tinymce) {
	global $spIsForum, $is_gecko, $is_opera, $is_safari, $is_chrome, $is_IE;

    if ($spIsForum) {
    	if ($is_safari) {
    		$tinymce = !wp_is_mobile() || (preg_match('!AppleWebKit/(\d+)!', $_SERVER['HTTP_USER_AGENT'], $match) && intval($match[1]) >= 534);
    	} elseif ($is_gecko || $is_chrome || $is_IE || ($is_opera && !wp_is_mobile())) {
    		$tinymce = true;
    	}
    }
	return $tinymce;
}

# ----------------------------------------------
# Display Textarea Input control
# ----------------------------------------------
function sp_tinymce_textarea($out, $areaid, $content, $editor, $tab) {
	if ($editor == RICHTEXT) {
        ob_start();
		include_once(SPTMLIB.'sp-tinymce-init.php');
	    $tm = sp_get_option('tinymce');
        $settings = array('wpautop' => false, 'media_buttons' => false, 'tinymce' => $tiny, 'dfw' => false, 'quicktags' => false, 'teeny' => false);
        wp_editor($content, $areaid, $settings);
		$out.= ob_get_contents();
		ob_end_clean();
	}
	return $out;
}

# ----------------------------------------------
# Add TinyMCE Admin Panel to Components
# ----------------------------------------------
function sp_tinymce_admin_menu() {
	$subpanels = array(
		__('Editor (TinyMCE)', 'sp-tinymce') => array('admin' => 'sp_tinymce_form', 'save' => 'sp_tinymce_save', 'form' => 1, 'id' => '')
	);
	sp_add_admin_subpanel('components', $subpanels);
}

# ----------------------------------------------
# Load the TinyMCE Options Admin Form
# ----------------------------------------------
function sp_tinymce_form() {
	include_once(SPTMADMIN.'sp-tinymce-components-form.php');
	sp_tinymce_options_form();
}

# ----------------------------------------------
# Save the TinyMCE Options Admin Form Data
# ----------------------------------------------
function sp_tinymce_save() {
	include_once(SPTMADMIN.'sp-tinymce-components-save.php');
	return sp_tinymce_options_save();
}

# ----------------------------------------------
# Action the Tinymce admin panel popup help
# ----------------------------------------------
function sp_tinymce_admin_help($file, $tag, $lang) {
    if ($tag == '[tinymce-options]' || $tag == '[tinymce-functions]' || $tag == '[tinymce-skins]') $file = SPTMDIR.'admin/sp-tinymce-admin-help.'.$lang;
    return $file;
}

# ----------------------------------------------
# Add tinymce to user profile editor option list
# ----------------------------------------------
function sp_tinymce_profile_option($edOpts, $userProfile) {
	$checked = ($userProfile->editor == RICHTEXT) ? $checked = 'checked="checked" ' : '';
	$edOpts.= '<p class="spProfileRadioLabel"><label for="sf-richtext"><span>'.__('Rich text', 'sp-tinymce').' - '.RICHTEXTNAME.'</span></label><input type="radio" '.$checked.'name="editor" id="sf-richtext" value="'.RICHTEXT.'"/></p>';
	return $edOpts;
}

function sp_tinymce_acknowledge($ack) {
	$ack[] = __('TinyMCE text editor by Moxiecode Systems', 'sp-tinymce').': <a href="http://www.moxiecode.com/">Moxiecode</a>';
	return $ack;
}
?>